@@ -27,7 +27,7 @@ def run(py_file):
 
 def demojize(py_path):
     """Replace emojis by strings in the given file"""
-    py_text = py_path.read_text()
+    py_text = py_path.read_text(encoding="utf-8")
     python_text = emoji.demojize(py_text, delimiters=DELIMITERS)
     return emojize_literals(python_text)
 
@@ -35,7 +35,7 @@ def demojize(py_path):
 class EmojiTransformer(ast.NodeTransformer):
     def visit_Str(self, node):
         return ast.copy_location(
-            ast.Str(s=emoji.emojize(node.s, delimiters=DELIMITERS)), node
+            ast.Constant(value=emoji.emojize(node.value, delimiters=DELIMITERS)), node
         )
 
 
@@ -50,7 +50,9 @@ def emojize_literals(text):
 
 def execute(py_path, python_ast):
     """Run Python on the given AST"""
-    exec(compile(python_ast, py_path, mode="exec"))
+    _source = compile(python_ast, py_path, mode="exec")
+    _globals = {}
+    exec(_source, _globals)
 
 
 if __name__ == "__main__":
